"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.autoRetry = void 0;
const promises_1 = require("node:timers/promises");
function autoRetry({ maxRetries = 3 } = {}) {
    return (call) => async (invocation) => {
        let retries = maxRetries;
        let promise;
        do {
            promise = call(invocation);
            try {
                const result = await promise;
                if (result.ok)
                    return result;
                if (result.error_code !== 429)
                    return result;
                const retryAfter = result.parameters?.retry_after ?? 5; // seconds
                await (0, promises_1.setTimeout)(retryAfter * 1000);
            }
            catch {
                // ignore the error for now, we may retry
            }
        } while (retries-- > 0);
        return await promise;
    };
}
exports.autoRetry = autoRetry;
